#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const os = require("os");
const path = require("path");
const fs = require("fs");
const child_process_1 = require("child_process");
/**
 * helper functions
 */
function install(targetFolder, packageName) {
    return __awaiter(this, void 0, void 0, function* () {
        const npmPath = require.resolve("yarn/package.json");
        const mainPath = require("yarn/package.json").bin.yarn;
        yield new Promise(res => require("mkdirp")(targetFolder, () => res()));
        const cp = child_process_1.fork(path.join(npmPath, "..", mainPath), ["add", packageName], { cwd: targetFolder });
        return new Promise(res => cp.once("exit", res));
    });
}
const fileExists = (path) => new Promise((r, j) => fs.stat(path, err => err ? r(false) : r(true)));
function detectArchitecture() {
    switch (os.platform()) {
        case 'darwin':
            return 'osx';
        case 'win32':
            switch (os.arch()) {
                case 'x64':
                    return 'win';
                case 'x86':
                    return 'win-x86';
            }
            break;
        case 'linux':
            return `linux`;
    }
    throw new Error(`Unsupported Platform: ${os.platform()}`);
}
/**
 * app
 */
const dotnetVersion = "2.0.0";
const pathOption = process.env.DOTNET_SHARED_HOME || path.normalize(`${os.homedir()}/.net/${dotnetVersion}`);
const archOption = process.env.DOTNET_SHARED_ARCH || detectArchitecture();
const packageName = `dotnet-${dotnetVersion}-${archOption}`;
function main() {
    return __awaiter(this, void 0, void 0, function* () {
        const force = process.argv.indexOf("--force") !== -1;
        // derive paths
        const packagePath = path.join(pathOption, `node_modules/${packageName}/`);
        const packageFilePath = packagePath + "package.json";
        try {
            // force? => remove folder first
            if (force) {
                yield new Promise((res, rej) => require("rimraf")(pathOption, (err) => err ? rej(err) : res()));
            }
            // install
            if (!(yield fileExists(packageFilePath))) {
                yield install(pathOption, packageName);
            }
            // validate
            if (!(yield fileExists(packageFilePath))) {
                throw new Error("Installation failed.");
            }
            fs.writeFileSync(path.join(__dirname, "package-path.json"), JSON.stringify(packagePath));
        }
        catch (e) {
            console.error(e);
            process.exit(1);
        }
    });
}
main();
//# sourceMappingURL=app.js.map